FeatureGovernanceState

Struct FeatureGovernanceState 

#[non_exhaustive]
pub struct FeatureGovernanceState { pub support_id: FeatureId, pub support_name: &'static str, pub support_description: &'static str, pub support_status: SupportStatus, pub doc_ref: Option<&'static str>, pub rationale: &'static str, pub required_feature_flags: &'static [Feature], pub missing_feature_flags: Vec<Feature>, pub runtime_enabled: bool, }
Runtime-aware governance state for a support matrix feature row.

Fields (Non-exhaustive)

This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.
support_id: FeatureId

Canonical support feature identifier from the support matrix.

support_name: &'static str

Human-readable support feature name.

support_description: &'static str

Short support feature description.

support_status: SupportStatus

Static support status from the support matrix.

doc_ref: Option<&'static str>

Reference to canonical docs row, when available.

rationale: &'static str

Why this support item is linked to feature flags.

required_feature_flags: &'static [Feature]

Runtime flags required to express this feature in an environment.

missing_feature_flags: Vec<Feature>

Runtime flags currently disabling this support item.

runtime_enabled: bool

Whether this support feature is currently fully enabled by active flags.

Implementations

Source

impl FeatureGovernanceState

pub fn from_support(feature: &'static FeatureSupport) -> Self

Build a non-governed runtime state row directly from static support metadata.